@@ -25,13 +25,15 @@ from cdpcli.extensions.df import (get_deployment_request_details,
                                   initiate_deployment,
                                   process_kpis,
                                   upload_workload_asset)
-from cdpcli.extensions.df.model import (DEPLOYMENT_ALERT,
+from cdpcli.extensions.df.model import (AWS_NODE_STORAGE_PROFILE,
+                                        DEPLOYMENT_ALERT,
                                         DEPLOYMENT_ALERT_THRESHOLD,
                                         DEPLOYMENT_FLOW_PARAMETER,
                                         DEPLOYMENT_FLOW_PARAMETER_GROUP,
                                         DEPLOYMENT_FREQUENCY_TOLERANCE,
                                         DEPLOYMENT_KEY_PERFORMANCE_INDICATOR,
-                                        LISTEN_COMPONENT)
+                                        LISTEN_COMPONENT,
+                                        VERSIONED_PARAMETER_GROUP_REFERENCES)
 from cdpcli.extensions.workload import set_workload_access_token
 from cdpcli.model import ObjectShape, OperationModel, ShapeResolver
 from cdpcli.utils import CachedProperty
@@ -266,6 +268,53 @@ OPERATION_SHAPES = {
                     'PERFORMANCE_AZURE'
                 ]
             },
+            'nodeStorage': {
+                'type': 'object',
+                'properties': {
+                    'azureContentRepoProfile': {
+                        'type': 'string',
+                        'description': 'The Azure content repository profile.',
+                        'enum': [
+                            'AZURE_P6',
+                            'AZURE_P10',
+                            'AZURE_P15',
+                            'AZURE_P30'
+                        ]
+                    },
+                    'azureProvenanceRepoProfile': {
+                        'type': 'string',
+                        'description': 'The Azure provenance repository profile.',
+                        'enum': [
+                            'AZURE_P6',
+                            'AZURE_P10',
+                            'AZURE_P15',
+                            'AZURE_P30'
+                        ]
+                    },
+                    'azureFlowFileRepoProfile': {
+                        'type': 'string',
+                        'description': 'The Azure flow file repository profile.',
+                        'enum': [
+                            'AZURE_P6',
+                            'AZURE_P10',
+                            'AZURE_P15',
+                            'AZURE_P30'
+                        ]
+                    },
+                    'awsContentRepoProfile': {
+                        'description': 'The AWS content repository profile.',
+                        '$ref': '#/definitions/AWSNodeStorageProfile'
+                    },
+                    'awsProvenanceRepoProfile': {
+                        'description': 'The AWS provenance repository profile.',
+                        '$ref': '#/definitions/AWSNodeStorageProfile'
+                    },
+                    'awsFlowFileRepoProfile': {
+                        'description': 'The AWS flow file repository profile.',
+                        '$ref': '#/definitions/AWSNodeStorageProfile'
+                    }
+                }
+            },
             'projectCrn': {
                 'type': 'string',
                 'description': 'CRN for the project to assign this deployment to. '
@@ -285,13 +334,15 @@ OPERATION_SHAPES = {
             }
         }
     },
+    'AWSNodeStorageProfile': AWS_NODE_STORAGE_PROFILE,
     'DeploymentFlowParameterGroup': DEPLOYMENT_FLOW_PARAMETER_GROUP,
     'DeploymentFlowParameter': DEPLOYMENT_FLOW_PARAMETER,
     'DeploymentKeyPerformanceIndicator': DEPLOYMENT_KEY_PERFORMANCE_INDICATOR,
     'DeploymentAlert': DEPLOYMENT_ALERT,
     'DeploymentAlertThreshold': DEPLOYMENT_ALERT_THRESHOLD,
     'DeploymentFrequencyTolerance': DEPLOYMENT_FREQUENCY_TOLERANCE,
-    'ListenComponent': LISTEN_COMPONENT
+    'ListenComponent': LISTEN_COMPONENT,
+    'VersionedParameterGroupReference': VERSIONED_PARAMETER_GROUP_REFERENCES
 }
 
 
@@ -556,6 +607,7 @@ class CreateDeploymentOperationCaller(CLIOperationCaller):
             'customNarConfigurationCrn': 'customNarConfigurationCrn',
             'customPythonConfigurationCrn': 'customPythonConfigurationCrn',
             'nodeStorageProfile': 'nodeStorageProfileName',
+            'nodeStorage': 'nodeStorage',
             'projectCrn': 'projectCrn'
         }
 
@@ -626,6 +678,14 @@ class CreateDeploymentOperationCaller(CLIOperationCaller):
         if nodeStorageProfileName is not None:
             deployment_configuration['nodeStorageProfileName'] = nodeStorageProfileName
 
+        # If nodeStorage is not set, then
+        # sending it as empty in the configuration will trigger
+        # dfx-local to assume and validate that the selected nodeStorageProfileName
+        # was not a custom profile for the given cloud platform
+        nodeStorage = parameters.get('nodeStorage', None)
+        if nodeStorage is not None:
+            deployment_configuration['nodeStorage'] = nodeStorage
+
         # If projectCrn is not set, then
         # sending it as empty in the configuration will trigger
         # dfx-local to not assign the created deployment to any project
